#!/usr/bin/env python


def wrapper_html(data, id, type="text/ng-template"):
    return """<script type="%s" id="/%s">\n%s\n</script>""" % (
        type, id, data
    )


def wrapper_jinja2(*args, **kwargs):
    html = wrapper_html(*args, **kwargs)

    return """{%% raw -%%}\n%s\n{%%- endraw -%%}""" % (html,)


def main():
    import argparse
    import os

    parser = argparse.ArgumentParser()
    parser.add_argument('templates', nargs='+',
                        help='The templates to collect.')
    parser.add_argument('-w', '--wrapper', choices=['html', 'jinja2'],
                        default='html')
    args = parser.parse_args()

    wrapper_func = globals()['wrapper_' + args.wrapper]
    buf = []
    for tplfn in args.templates:
        buf.append(wrapper_func(open(tplfn).read(),
                                os.path.basename(tplfn)))

    print '\n\n'.join(buf)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os

from setuptools import setup, find_packages


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


setup(
    name='ngtpl',
    version='0.2.2',
    description='Collect angular templates, outputs compiled html',
    #long_description=read('README.rst'),
    author='Marc Brinkmann',
    author_email='git@marcbrinkmann.de',
    url='http://github.com/mbr/ngtpl',
    license='MIT',
    packages=find_packages(exclude=['test']),
    install_requires=[],
    entry_points={
        'console_scripts': [
            'ngtpl = ngtpl:main',
        ],
    }
)
